@@ -1,7 +1,7 @@
 /*
 This file is part of Choqok, the KDE micro-blogging client
 
-Copyright (C) 2008-2010 Mehrdad Momeny <mehrdad.momeny@gmail.com>
+Copyright (C) 2008-2011 Mehrdad Momeny <mehrdad.momeny@gmail.com>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
@@ -52,6 +52,7 @@ along with this program; if not, see http://www.gnu.org/licenses/
 #include "twitterapicomposerwidget.h"
 #include <QtOAuth/QtOAuth>
 #include <choqokappearancesettings.h>
+#include "application.h"
 
 class TwitterApiMicroBlog::Private
 {
@@ -270,9 +271,11 @@ void TwitterApiMicroBlog::saveTimeline(Choqok::Account *account,
         grp.writeEntry( "repeatedPostId", post->repeatedPostId.toString());
     }
     postsBackup.sync();
-    --d->countOfTimelinesToSave;
-    if(d->countOfTimelinesToSave < 1)
-        emit readyForUnload();
+    if(Choqok::Application::isShuttingDown()) {
+        --d->countOfTimelinesToSave;
+        if(d->countOfTimelinesToSave < 1)
+            emit readyForUnload();
+    }
 }
 
 Choqok::UI::ComposerWidget* TwitterApiMicroBlog::createComposerWidget(Choqok::Account* account, QWidget* parent)
