@@ -1,7 +1,7 @@
 /*
     This file is part of Choqok, the KDE micro-blogging client
 
-    Copyright (C) 2010 Mehrdad Momeny <mehrdad.momeny@gmail.com>
+    Copyright (C) 2010-2011 Mehrdad Momeny <mehrdad.momeny@gmail.com>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -101,10 +101,16 @@ void FilterManager::parse(Choqok::UI::PostWidget* postToParse)
 
     if(!postToParse)
         return;
-
+    kDebug()<<"Processing: "<<postToParse->content();
     foreach(Filter* filter, FilterSettings::self()->filters()) {
         if(filter->filterText().isEmpty())
             return;
+        if(filter->dontHideReplies() &&
+            (postToParse->currentPost().replyToUserName.compare(postToParse->currentAccount()->username(),
+                                                                Qt::CaseInsensitive) == 0 ||
+             postToParse->currentPost().content.contains(QString("@%1").arg(postToParse->currentAccount()->username())))
+          )
+            continue;
         switch(filter->filterField()){
             case Filter::Content:
                 doFiltering( postToParse, filterText(postToParse->currentPost().content, filter) );
@@ -129,25 +135,25 @@ FilterManager::FilterAction FilterManager::filterText(const QString& textToCheck
     switch(filter->filterType()){
         case Filter::ExactMatch:
             if(textToCheck == filter->filterText()){
-                kDebug()<<"ExactMatch";
+                kDebug()<<"ExactMatch: " << filter->filterText();
                 return Remove;
             }
             break;
         case Filter::RegExp:
             if( textToCheck.contains(QRegExp(filter->filterText())) ){
-                kDebug()<<"RegExp";
+                kDebug()<<"RegExp: " << filter->filterText();
                 return Remove;
             }
             break;
         case Filter::Contain:
             if( textToCheck.contains(filter->filterText()) ){
-                kDebug()<<"Contain";
+                kDebug()<<"Contain: " << filter->filterText();
                 return Remove;
             }
             break;
         case Filter::DoesNotContain:
             if( !textToCheck.contains(filter->filterText()) ){
-                kDebug()<<"DoesNotContain";
+                kDebug()<<"DoesNotContain: " << filter->filterText();
                 return Remove;
             }
             break;
